@@ -5,8 +5,8 @@ from datetime import UTC, datetime
 
 from awscrt import mqtt
 
-from nwp500.mqtt_client import MqttConnectionConfig
-from nwp500.mqtt_utils import QueuedCommand
+from nwp500.mqtt import MqttConnectionConfig
+from nwp500.mqtt.utils import QueuedCommand
 
 
 def test_queued_command_dataclass():
